@@ -76,6 +76,13 @@ def date_range_params(period_config, comparison, period, reference_date):
         start_date = (today + relativedelta(days=-14)).strftime("%Y-%m-%d")
         end_date = (today + relativedelta(days=-7)).strftime("%Y-%m-%d")
 
+    elif period_config == "ly":
+        start_date = (today + relativedelta(years=-1)).strftime("%Y-01-01")
+        end_date = today.strftime("%Y-01-01")
+
+    elif period_config == "month_ly":
+        start_date = (today + relativedelta(years=-1)).strftime("%Y-%m-01")
+        end_date = (today + relativedelta(years=-1) + relativedelta(months=1)).strftime("%Y-%m-01")
 
 
     else:
@@ -114,6 +121,9 @@ class DataSource:
     def _build_folder_path(self, layer_name):
         return self.path_to_datasource_folder + 'layers/' + layer_name + "/"
 
+    def _build_root_folder_path(self):
+        return self.path_to_datasource_folder
+
     def load_file(self, path):
         if self.loader_function is None:
             return open(path).read()
@@ -154,10 +164,14 @@ class DataSource:
         jinja_env = jinja2.Environment()
 
         params = {}
-        if os.path.isfile(folder_path + "params.yaml"):
+        if os.path.isfile(self._build_root_folder_path() + "params.yaml"):
             params = yaml.load(
-                jinja_env.from_string(open(folder_path + "params.yaml").read()).render(),
+                jinja_env.from_string(open(self._build_root_folder_path() + "params.yaml").read()).render(),
                 Loader=yaml.FullLoader)
+        if os.path.isfile(folder_path + "params.yaml"):
+            params.update(yaml.load(
+                jinja_env.from_string(open(folder_path + "params.yaml").read()).render(),
+                Loader=yaml.FullLoader))
         config = yaml.load(
             jinja_env.from_string(open(folder_path + "config.yaml").read()).render(params),
             Loader=yaml.FullLoader)
@@ -212,15 +226,6 @@ class DataSource:
             )
             )
 
-        if query_config.get("daterange"):
-            dict_params.update(date_range_params(
-                period_config=query_config.get("daterange"),
-                comparison=False,
-                period=None,
-                reference_date=reference_date
-            )
-            )
-
         if query_config.get("period_comparison"):
             dict_params.update(date_range_params(
                 period_config=query_config.get("period_comparison"),
